@@ -1,5 +1,5 @@
 import io
-from PIL import Image, ImageTk
+from PIL import Image, ImageTk, ImageDraw
 
 
 def load_image_from_byte_array(byte_array: bytes) -> Image.Image:
